/**
 * Componente que irá exibir qualquer conteúdo em qualquer screen
 *
 * @author                        Marlon Saldanha
 * @param children                Componente a ser renderizado.
 * @param roundedBottom           Por padrão, o componente é renderizado apenas com as bordas
 *                                superiores arredondadas. Este parâmetro define que as bordas
 *                                inferiores também irão ficar arredondadas.
 * @param buttonText              Texto do botão que fica localizado na parte de baixo da tela
 * @param buttonAction            Ação do botão que fica localizado na parte de baixo da tela
 * @param buttonBackgroundColor   Cor de fundo do botão que fica localizado na parte de baixo da tela
 * @param buttonTextColor         Cor do texto do botão que fica localizado na parte de baixo da tela
 * @param buttonDisabled          Condição para diesativar o botão que fica localizado na parte de baixo da tela
 * @param buttonIcon              Icone do botão que fica localizado na parte de baixo da tela
 * @param divisor                 Linha divisória que separa o botão do resto do conteudo
 * @param style                   Estilo para o Body
 * @param notSpaced               Definição para não separar os itens com space-between
 *
 * @example               <Body
 *                          buttonAction={funcao}
 *                          buttonDisabled={true}
 *                          buttonText="Próximo"
 *                          buttonBackgroundColor={colors.primary}
 *                          buttonTextColor={colors.textWhite}
 *                          buttonIcon={'arrow'}
 *                          notSpaced
 *                          divisor
 *                         >
 *                          Aqui você passa qualquer componente
 *                        </BodyComponent>
 */

import React from 'react';
import { ScrollView, StyleSheet, View, Text } from 'react-native';
import colors from '../constants/colors';
import ButtonComponent from './ButtonComponent';

export default function BodyComponent({
  children,
  roundedBottom,

  buttonText,
  buttonAction,
  buttonBackgroundColor,
  buttonTextColor,

  buttonDisabled,
  buttonIcon,
  divisor,
  style,
  notSpaced,
}) {
  return (
    <View
      style={[styles.rounded, roundedBottom && styles.roundedBottom, style]}
    >
      <ScrollView
        contentContainerStyle={[styles.body, notSpaced && styles.notSpaced]}
      >
        {children}
        {buttonAction && (
          <View style={[styles.button, divisor && styles.divisor]}>
            <ButtonComponent
              text={buttonText}
              backgroundColor={buttonBackgroundColor}
              textColor={buttonTextColor}
              action={buttonAction}
              disabled={buttonDisabled}
              icon={buttonIcon}
            />
          </View>
        )}
      </ScrollView>
    </View>
  );
}

const styles = StyleSheet.create({
  body: {
    flexGrow: 1,
    justifyContent: 'space-between',
    paddingHorizontal: 20,
    paddingTop: 20,
  },
  rounded: {
    flex: 1,
    backgroundColor: colors.background,
    borderTopStartRadius: 10,
    borderTopEndRadius: 10,
  },
  notSpaced: {
    justifyContent: 'flex-start',
  },
  button: {
    alignItems: 'center',
  },
  divisor: {
    borderTopColor: colors.primary,
    borderTopWidth: 2,
  },

  roundedBottom: {
    borderBottomStartRadius: 10,
    borderBottomEndRadius: 10,
  },
});
