/**
 * Componente de modelo que cria um botão
 *
 * @author                Enzo Russo e João Leão
 * @param text            Texto do botão para as ações do Tutorial
 * @param backgroundColor Parametro OPCIONAL para modificar a cor do botão
 * @param disabled        Parametro OPCIONAL para desabilitar o botão
 * @param textColor       Parametro OPCIONAL para modificar a cor do texto e da borda do botão
 * @param icon            Parametro OPCIONAL para adicionar icone ao botão (seguindo o esquema de cores)
 * @param action          Parametro para indicar a ação que o botão vai realizar
 * @example               <ButtonComponent
 *                          text="Salvar"
 *                          backgroundColor={colors.background}
 *                          textColor={colors.primary}
 *                          action={console.log('teste')}
 *                          disabled
 *                          icon='feather'
 *                        />
 */

import { Row } from 'native-base';
import React, { useState } from 'react';
import { StyleSheet, TouchableOpacity, Text } from 'react-native';
import Icon from 'react-native-vector-icons/Feather';
import colors from '../constants/colors';

export default function ButtonComponent({
  text,
  textColor = colors.primary,
  backgroundColor,
  disabled,
  icon,
  action,
  margin = 20,
  style,
}) {
  return (
    <TouchableOpacity
      onPress={e => action()}
      disabled={disabled}
      style={[
        styles.button,
        {
          borderColor: textColor,
          backgroundColor: backgroundColor,
        },
        { marginVertical: margin },
        disabled && styles.disabled,
        style,
      ]}
      activeOpacity={0.6}
    >
      <Text
        style={[
          styles.text,
          {
            color: textColor,
          },
          disabled && {
            color: colors.background,
          },
        ]}
      >
        {text}
      </Text>
      <Icon
        style={[
          styles.icon,
          {
            color: textColor,
          },
        ]}
        name={icon}
        size={25}
      />
    </TouchableOpacity>
  );
}

const styles = StyleSheet.create({
  button: {
    flexDirection: 'row',
    width: 300,
    height: 50,
    alignItems: 'center',
    justifyContent: 'center',
    borderRadius: 8,
    borderWidth: 3,
  },
  buttonMargin: {
    marginVertical: 0,
  },
  icon: {
    position: 'absolute',
    right: 10,
  },
  text: {
    fontSize: 18,
    fontWeight: 'bold',
  },
  disabled: {
    borderColor: colors.background,
    backgroundColor: colors.backgroundDisabled,
  },
});
