/**
 * Componente que renderiza um header (cabeçalho), podendo ter children(filhos) ou não.
 *
 * @author                  Marlon Saldanha
 * @param leftButton        Botão OPCIONAL que fica à esquerda do cabeçalho.
 *                          Sua função é voltar para a navegação anterior
 * @param rightButton       Botão OPCIONAL que fica à direita do cabeçalho.
 *                          Sua função é disparar uma ação que leva para alguma screen específica.
 *                          Obs: Deve-se informar qual o título e caminho que você quer no botão.
 *                          Lembre-se que este caminho deve estar registrado em routes.js
 * @param large             Atributo OPCIONAL que define se você quer o tamanho do header em 200px.
 *                          Por padrão o tamanho é 156px.
 * @param children          Qualquer componente que será passado como conteúdo-filho do cabeçalho.
 *
 * @example                 <HeaderComponent
 *                            large
 *                            leftButton
 *                            rightButton={{
 *                              label: 'Pular',
 *                              to: 'ModelScreen',
 *                            }}
 *                          >
 *                            children
 *                          </HeaderComponent>
 *
 * @example                 <HeaderComponent leftButton />
 */

import React from 'react';
import { View, StyleSheet, TouchableOpacity, Text } from 'react-native';
import Icon from 'react-native-vector-icons/Feather';

export default function HeaderComponent({
  leftButton,
  rightButton,
  large,
  children,
  rightButtonAction,
  leftButtonAction,
}) {
  return (
    <View style={[styles.container, large && styles.largeContainer]}>
      <View
        style={
          !leftButton
            ? styles.buttonsContainerWithoutLeftButton
            : styles.buttonsContainer
        }
      >
        {leftButton && (
          <TouchableOpacity onPress={leftButtonAction}>
            <Icon name="arrow-left" size={25} color={'#fff'} />
          </TouchableOpacity>
        )}

        {rightButton && (
          <TouchableOpacity onPress={rightButtonAction}>
            <Text style={styles.rightButton}>{rightButton}</Text>
          </TouchableOpacity>
        )}
      </View>

      <View style={styles.childrens}>{children}</View>
    </View>
  );
}

const styles = StyleSheet.create({
  container: {
    paddingTop: 50,
    paddingHorizontal: 20,
    width: '100%',
  },
  childrens: {
    paddingBottom: 30,
    alignItems: 'center',
    justifyContent: 'center',
    paddingTop: 20,
  },
  buttonsContainerWithoutLeftButton: {
    flexDirection: 'row-reverse',
    justifyContent: 'space-between',
    height: 25,
  },
  buttonsContainer: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    width: '100%',
    height: 25,
  },
  rightButton: {
    color: '#fff',
    fontSize: 19,
    fontWeight: 'bold',
  },
});
