/**
 * Tela de modelo com um componente de modelo
 *
 * @author            Arthur Oliano, Enzo Russo
 * @example           <CreateAccountScreen/>
 */

import React, { useEffect, useState } from 'react';
import {
  StyleSheet,
  View,
  Text,
  TouchableOpacity,
  Linking,
  AsyncStorage,
} from 'react-native';
import Header from '../components/HeaderComponent';
import Body from '../components/BodyComponent';
import ButtonComponent from '../components/ButtonComponent';
import InputText from '../components/InputTextComponent';
import LoaderComponent from '../components/LoaderComponent';
import SelectComponent from '../components/SelectComponent';
import colors from '../constants/colors';
import states from '../constants/states';
import ButtonGroupComponent from '../components/ButtonGroupComponent';
import Icon from 'react-native-vector-icons/Feather';
import api from '../api';

export default function CreateAccountScreen({ navigation }) {
  const [chosenOptionState, setChosenOptionState] = useState(null);
  const [chosenOptionYear, setChosenOptionYear] = useState(null);
  const [name, setName] = useState('');
  const [email, setEmail] = useState('');
  const [password, setPassword] = useState('');
  const [gender, setGender] = useState('Masculino');
  const [city, setCity] = useState('');
  const [icon, setIcon] = useState('square');
  const [accepted, setAccepted] = useState(false);
  const [years, setYears] = useState([]);
  const [isValid, setIsValid] = useState(false);
  const [isLoading, setIsLoading] = useState(false);

  useEffect(() => {
    const stringFields = [name, email, password, chosenOptionState, city];
    const stringFieldsValid = stringFields.every(
      s => (s ?? '').trim().length > 0,
    );
    const yearValid =
      chosenOptionYear !== null && chosenOptionYear !== undefined;
    setIsValid(stringFieldsValid && yearValid && accepted);
  }, [
    name,
    email,
    password,
    chosenOptionYear,
    chosenOptionState,
    city,
    accepted,
  ]);

  const saveUserId = async userId => {
    try {
      await AsyncStorage.setItem('userId', `${userId}`);
    } catch (error) {
      console.log(error.message);
    }
  };

  useEffect(() => {
    const currYear = new Date().getFullYear();

    const years = [];
    for (let year = 1900; year <= currYear; year++) {
      years.push({ name: `${year}`, value: year });
    }

    setYears(years);
  }, []);

  function changeIcon() {
    if (icon === 'square') {
      setIcon('check-square');
      setAccepted(true);
    } else {
      setIcon('square');
      setAccepted(false);
    }
  }

  function changeGender(option) {
    switch (option) {
      case 0:
        setGender('Masculino');
        break;
      case 1:
        setGender('Feminino');
        break;
      case 2:
        setGender('Outro');
        break;
    }
  }

  const state = states.map(state => ({ value: state.value, name: state.name }));

  const registerUser = async () => {
    setIsLoading(!isLoading);
    const response = await api.post('/user/registration', {
      name,
      email: email.toLowerCase(),
      password,
      gender,
      city,
      uf: chosenOptionState,
      birthYear: chosenOptionYear,
    });

    if (response.data.status == 400) {
      Alert.alert('Falha no cadastro', 'Este e-mail já está cadastrado');
    } else {
      saveUserId(response.data.data.id);
      navigation.navigate('SignupAppSelectionScreen');
    }
    setIsLoading(!isLoading);
  };

  return isLoading ? (
    <LoaderComponent isActivityIndicator="false" />
  ) : (
    <View style={styles.screen}>
      <Header
        large
        leftButton
        leftButtonAction={e => navigation.navigate('LoginScreen')}
      >
        <Text style={styles.title}>
          Para nos ajudar a melhorar sua {''}experiência,
          <Text style={styles.textBold}> cadastre-se</Text> na plataforma. É
          rápido :)
        </Text>
      </Header>
      <Body
        buttonAction={registerUser}
        buttonText="Cadastrar"
        buttonBackgroundColor={colors.primary}
        buttonTextColor={colors.textWhite}
        buttonDisabled={!isValid}
      >
        <InputText
          style={styles.input}
          placeholder="Qual o seu nome?*"
          onChangeText={name => setName(name)}
          errorMessage="Campo obrigatório"
        />
        <InputText
          style={styles.input}
          autoCapitalize="none"
          placeholder="Digite seu email*"
          emailType
          onChangeText={email => setEmail(email)}
          errorMessage="Campo obrigatório"
        />

        <InputText
          style={styles.input}
          placeholder="Vamos criar uma senha?*"
          onChangeText={password => setPassword(password)}
          errorMessage="Campo obrigatório"
          passwordType
        />

        <ButtonGroupComponent
          style={styles.input}
          label="Gênero"
          options={['Masculino', 'Feminino', 'Outro']}
          onChange={changeGender}
        />
        <SelectComponent
          style={styles.input}
          errorMessage="Nenhum item foi selecionado"
          onChange={setChosenOptionYear}
          placeholder="Em que ano você nasceu?*"
          items={years}
        />
        <SelectComponent
          style={styles.input}
          errorMessage="Nenhum item foi selecionado"
          onChange={setChosenOptionState}
          placeholder="Seu estado de residência?*"
          items={state}
        />
        <InputText
          style={styles.input}
          placeholder="Sua cidade de residência?*"
          onChangeText={city => setCity(city)}
          errorMessage="Campo obrigatório"
        />
        <View style={styles.termsView}>
          <TouchableOpacity>
            <Icon
              name={icon}
              size={22}
              color={colors.textDisabled}
              onPress={_e => changeIcon()}
            />
          </TouchableOpacity>
          <Text style={styles.fontSizeAccept}> Aceito os</Text>
          <TouchableOpacity
            style={styles.buttonContainer}
            onPress={() => Linking.openURL('https://appoiodigital.com/termos/')}
          >
            <Text style={styles.terms}> termos de uso</Text>
          </TouchableOpacity>
        </View>
      </Body>
    </View>
  );
}
const styles = StyleSheet.create({
  screen: {
    flex: 1,
    backgroundColor: colors.primary,
    alignItems: 'center',
  },
  title: {
    color: colors.textWhite,
    fontSize: 22,
    textAlign: 'center',
  },
  textBold: {
    fontWeight: 'bold',
  },
  buttonContainer: {
    alignItems: 'center',
  },
  terms: {
    color: colors.primary,
    textDecorationLine: 'underline',
    fontWeight: 'bold',
    fontSize: 18,
    borderRightWidth: 200,
    borderRightColor: colors.background,
  },
  fontSizeAccept: {
    fontSize: 18,
  },
  termsView: {
    justifyContent: 'space-between',
    flexDirection: 'row',
  },
  input: {
    paddingBottom: 20,
  },
});
