/**
 * Tela de modelo com um componente de modelo
 *
 * @author            João Leão, Arthur Henz e Felipe Hamester
 * @example           <ModelScreen/>
 */

import React, { useState } from 'react';
import {
  StyleSheet,
  View,
  Image,
  Text,
  Platform,
  Dimensions,
  AsyncStorage,
} from 'react-native';
import api from '../api';

import TabSelectionComponent from '../components/TabSelectionComponent';
import BodyComponent from '../components/BodyComponent';
import HeaderComponent from '../components/HeaderComponent';
import ListComponent from '../components/ListComponent';
import colors from '../constants/colors';
import AppButtonComponent from '../components/AppButtonComponent';
import ButtonComponent from '../components/ButtonComponent';
import SearchBarComponent from '../components/SearchBarComponent';

import APPS from '../constants/apps';

export default function HomeScreen({ navigation }) {
  const [selectedTab, setSelectedTab] = useState(0);
  const [data, setData] = useState([]);
  const [dataCelular, setDataCelular] = useState([]);
  const [allAppsInstalled, setAllAppsInstalled] = useState([]);
  const [appsInstalled, setInstalled] = useState([]);
  const [appsNotInstalled, setNotInstalled] = useState([]);
  const [noResultMessage, setNoResultMessage] = useState(
    'Nenhum resultado encontrado',
  );
  const [isLogged, setIsLogged] = useState(false);
  const [searching, setSearching] = useState(false);
  const [filteredData, setFilteredData] = useState([]);
  const [searchedText, setSearchedText] = useState('');

  async function goBack() {
    navigation.navigate('AppSelectionScreen', { allAppsInstalled });
  }

  async function handleSearch() {
    if (searchedText.length != 0) {
      setSearching(true);

      const response = await api.get(`tutorial/search/${searchedText}`);
      const { data } = response.data;
      const { status } = data;
      setFilteredData(data);
      if (status === 500) {
        Alert.alert(
          'Falha ao procurar tutoriais',
          'Houve um problema ao tentar buscar tutoriais. Tente novamente mais tarde.',
        );
      }
    }
  }

  async function handleSearchChange(text) {
    if (text.length > 0) {
      setSearchedText(text);
    } else {
      setSearching(false);
    }
  }

  function filterTutorialsForOS(tutorials) {
    return (tutorials ?? []).filter(tutorial => {
      const os = (tutorial.operatingSystem ?? '').trim();
      if (os.length === 0) {
        return true;
      }

      return os.toLowerCase() === Platform.OS;
    });
  }

  React.useEffect(() => {
    async function isLogged() {
      try {
        const isLogged = await AsyncStorage.getItem('userId');
        setIsLogged(!!isLogged);
      } catch (error) {
        console.warn(error);
      }
    }
    async function fetchApps() {
      try {
        const APPS = await api.get(`/app/all`);
        const appsInstalled = APPS.data.data.Installed;
        const appsNotInstalled = APPS.data.data.NotInstalled;
        if (appsInstalled?.length != 0) setInstalled(appsInstalled);
        else setInstalled([]);

        if (appsNotInstalled?.length != 0) setNotInstalled(appsNotInstalled);
        else setNotInstalled([]);

        const allInstalledRes = await api.get('/app/installed');
        const allInstalled = allInstalledRes.data.data;

        if (allInstalled.length != 0) setAllAppsInstalled(allInstalled);
        else setAllAppsInstalled([]);
      } catch (error) {
        console.warn(error);
      }
    }
    async function fetchData() {
      try {
        const response = await api.get(`/tutorial/categories/1`);
        setData(response.data.data);
        setDataCelular(filterTutorialsForOS(response.data.data.celular));
      } catch (error) {
        console.warn(error);
      }
    }
    fetchApps();
    fetchData();
    isLogged();
  }, [selectedTab]);

  const emptyMessage = (
    text = 'Não existem tutoriais desta categoria ainda.',
  ) => (
    <View style={styles.emptyMessageContainer}>
      <Text style={styles.emptyMessage}>{text}</Text>
    </View>
  );

  const width = Dimensions.get('screen').width - 40;
  const cardSize = width * 0.3;

  return (
    <View style={styles.screen}>
      <HeaderComponent large>
        <Image
          style={{
            alignSelf: 'center',
            width: 90,
            height: 46,
            marginBottom: 10,
          }}
          source={require('../../assets/logo-p.png')}
        />
        <SearchBarComponent
          placeholder={'Buscar por títulos ou tags'}
          handleEnter={() => handleSearch()}
          handleChange={handleSearchChange}
        />
      </HeaderComponent>

      <BodyComponent notSpaced>
        {searching ? (
          filteredData.length > 0 ? (
            <ListComponent
              appoios={filteredData}
              action={id => navigation.navigate('Tutorial', { id })}
            />
          ) : (
            emptyMessage(noResultMessage)
          )
        ) : (
          <View>
            <TabSelectionComponent
              style={{ marginBottom: 10 }}
              tabSelected={selectedTab}
              onPress={index => setSelectedTab(index)}
            >
              <View title="APLICATIVOS" style={styles.content} />
              <View title="CELULAR" style={styles.content} />
              <View title="CONCEITOS" style={styles.content} />
            </TabSelectionComponent>
            {selectedTab == 0 &&
              (appsInstalled.length != 0 || appsNotInstalled.length != 0 ? (
                <View>
                  {isLogged && (
                    <View>
                      <Text style={styles.message}>Aplicativos instalados</Text>
                      {appsInstalled.length == 0 &&
                        emptyMessage('Nenhum aplicativo adicionado.')}
                      <View style={styles.aplicativos}>
                        {appsInstalled.map(id => {
                          let name = '';
                          let image = '';
                          for (let i = 0; i < APPS.length; i++) {
                            if (id == APPS[i].id) {
                              name = APPS[i].name;
                              image = APPS[i].image;
                            }
                          }
                          return (
                            <AppButtonComponent
                              key={id}
                              action={e =>
                                navigation.navigate('TutorialListScreen', {
                                  id,
                                  name,
                                })
                              }
                              name={name}
                              image={image}
                            />
                          );
                        })}
                        {appsInstalled.length % 3 != 0 && (
                          <View style={{ width: cardSize, height: cardSize }} />
                        )}
                      </View>
                      <View style={styles.buttonContainer}>
                        <ButtonComponent
                          text={
                            appsInstalled.length !== 0
                              ? 'Adicionar mais aplicativos'
                              : 'Adicionar aplicativos'
                          }
                          backgroundColor={colors.primary}
                          textColor={colors.textWhite}
                          action={goBack}
                        />
                      </View>
                    </View>
                  )}
                  {appsNotInstalled.length != 0 && (
                    <View style={styles.grayBackground}>
                      <Text style={styles.message}>
                        Todos os aplicativos com tutorial
                      </Text>
                      <View style={styles.aplicativos}>
                        {appsNotInstalled.map(id => {
                          let name = '';
                          let image = '';
                          for (let i = 0; i < APPS.length; i++) {
                            if (id == APPS[i].id) {
                              name = APPS[i].name;
                              image = APPS[i].image;
                            }
                          }
                          return (
                            <AppButtonComponent
                              key={id}
                              action={e =>
                                navigation.navigate('TutorialListScreen', {
                                  id,
                                  name,
                                })
                              }
                              name={name}
                              image={image}
                            />
                          );
                        })}
                        {appsNotInstalled.length % 3 != 0 && (
                          <View style={{ width: cardSize, height: cardSize }} />
                        )}
                      </View>
                    </View>
                  )}
                </View>
              ) : (
                emptyMessage()
              ))}
            {selectedTab == 1 &&
              ((dataCelular ?? []).length > 0 ? (
                <ListComponent
                  appoios={dataCelular}
                  action={id => navigation.navigate('Tutorial', { id })}
                />
              ) : (
                emptyMessage()
              ))}
            {selectedTab == 2 &&
              (data.conceitos ? (
                <ListComponent
                  appoios={data.conceitos}
                  action={id => navigation.navigate('Tutorial', { id })}
                />
              ) : (
                emptyMessage()
              ))}
          </View>
        )}
      </BodyComponent>
    </View>
  );
}
const styles = StyleSheet.create({
  screen: {
    flex: 1,
    backgroundColor: colors.primary,
  },
  emptyMessage: {
    color: colors.textDisabled,
    fontSize: 20,
    fontWeight: 'bold',
    textAlign: 'center',
    alignSelf: 'center',
  },
  message: {
    marginVertical: 10,
    marginHorizontal: 15,
    color: '#000000',
    fontSize: 20,
    fontWeight: 'bold',
    justifyContent: 'center',
  },
  emptyMessageContainer: {
    marginVertical: '10%',
    justifyContent: 'center',
  },
  aplicativos: {
    flexDirection: 'row',
    flexWrap: 'wrap',
    justifyContent: 'space-between',
  },
  buttonContainer: {
    alignItems: 'center',
  },
  body: {
    padding: 0,
    paddingTop: 20,
  },
  appsInstalledSection: {
    paddingBottom: 20,
  },
  grayBackground: {
    backgroundColor: colors.backgroundSection,
    borderRadius: 15,
  },
});
