/**
 * Tela de login para usuario comum e administrador
 *
 * @author          Marlon Saldanha, Pablo Alles
 * @example         <LoginScreen />
 */

import React, { useState } from 'react';
import {
  StyleSheet,
  View,
  Text,
  ScrollView,
  Alert,
  TouchableOpacity,
  AsyncStorage,
} from 'react-native';
import api from '../api';
import colors from '../constants/colors';

import { CommonActions } from '@react-navigation/native';
import Header from '../components/HeaderComponent';
import BodyComponent from '../components/BodyComponent';
import InputTextComponent from '../components/InputTextComponent';
import ButtonComponent from '../components/ButtonComponent';
import FooterComponent from '../components/FooterComponent';
import LoaderComponent from '../components/LoaderComponent';

export default function LoginScreen({ navigation }) {
  const [email, setEmail] = useState(null);
  const [password, setPassword] = useState(null);
  const [isLoading, setIsLoading] = useState(false);

  const saveAsyncStorage = async (key, value) => {
    try {
      await AsyncStorage.setItem(key, `${value}`);
    } catch (error) {
      console.log(error.message);
    }
  };

  async function handleLogin() {
    setIsLoading(!isLoading);
    const response = await api.post('user/login', {
      email: email.toLowerCase(),
      password,
    });

    if (response.data.status === 401) {
      Alert.alert(
        'Falha no login',
        'Parece que seu email ou senha estão incorretos',
      );
    } else if (response.data.status === 200) {
      const { id, admin } = response.data.data;
      saveAsyncStorage('userId', id);
      saveAsyncStorage('email', email.toLowerCase());
      saveAsyncStorage('isAdmin', admin);

      const homeRouteName = admin ? 'AdminRoot' : 'Root';

      navigation.dispatch(
        CommonActions.reset({
          index: 0,
          routes: [{ name: homeRouteName }],
        }),
      );
    } else {
      Alert.alert(
        'Falha no login',
        'Houve um problema ao tentar fazer login. Tente novamente mais tarde.',
      );
    }
    setIsLoading(!isLoading);
  }

  function createAccount() {
    navigation.navigate('CreateAccountScreen');
  }

  return isLoading ? (
    <LoaderComponent isActivityIndicator="false" />
  ) : (
    <ScrollView style={styles.screen}>
      <Header large>
        <Text style={styles.title}>Bem-vindo!</Text>
      </Header>
      <BodyComponent roundedBottom>
        <View style={styles.fieldContainer}>
          <InputTextComponent
            placeholder="E-mail"
            emailType
            onChangeText={value => setEmail(value)}
          />
          <InputTextComponent
            placeholder="Senha"
            passwordType={true}
            onChangeText={value => setPassword(value)}
          />
        </View>
        <View style={styles.buttonsContainer}>
          <ButtonComponent
            text="Entrar"
            backgroundColor={
              !email || !password ? colors.backgroundDisabled : colors.primary
            }
            disabled={!email || !password}
            textColor={colors.textWhite}
            action={handleLogin}
          />
          <TouchableOpacity onPress={createAccount}>
            <Text style={styles.cadastro}>Cadastre-se</Text>
          </TouchableOpacity>
        </View>
      </BodyComponent>
      <FooterComponent>
        <ButtonComponent
          text="Preciso de ajuda para fazer login"
          backgroundColor={colors.textWhite}
          textColor={colors.primary}
          action={() =>
            Alert.alert(
              'Em desenvolvimento',
              'Esta funcionalidade ainda não está implementada',
              [{ text: 'OK' }],
            )
          }
          //TODO redirecionar para o tutorial de login
          //() => navigation.navigate('ModelScreen')
          margin={0}
        />
        <ButtonComponent
          text="Continuar sem cadastro"
          backgroundColor={colors.primary}
          textColor={colors.textWhite}
          action={() => navigation.navigate('Root')}
        />
      </FooterComponent>
    </ScrollView>
  );
}

const styles = StyleSheet.create({
  screen: {
    flex: 1,
    backgroundColor: colors.primary,
  },
  header: {
    alignItems: 'center',
    justifyContent: 'center',
    color: colors.textWhite,
    fontSize: 30,
    fontWeight: 'bold',
  },
  headerDescription: {
    alignItems: 'center',
    textAlign: 'center',
    justifyContent: 'center',
    color: colors.textWhite,
    fontSize: 25,
  },
  title: {
    color: colors.textWhite,
    fontSize: 40,
    fontWeight: 'bold',
  },
  fieldContainer: {
    marginTop: 50,
  },
  cadastro: {
    fontSize: 20,
    fontWeight: 'bold',
    textDecorationLine: 'underline',
  },
  buttonsContainer: {
    flex: 1,
    marginBottom: 20,
    alignItems: 'center',
  },
});
