/**
 * Tela de modelo com um componente de modelo
 *
 * @author            João Leão
 * @example           <ModelScreen/>
 */

import React from 'react';
import { StyleSheet, View, Text, Platform } from 'react-native';
import colors from '../constants/colors';
import api from '../api';

import HeaderComponent from '../components/HeaderComponent';
import BodyComponent from '../components/BodyComponent';
import ListComponent from '../components/ListComponent';
import SearchBarComponent from '../components/SearchBarComponent';

export default function TutorialListScreen({ route, navigation }) {
  const [tutorials, setTutorials] = React.useState([]);
  const [searchText, setSearchText] = React.useState('');
  const [filteredData, setFilteredData] = React.useState([]);
  const [noResultMessage, setNoResultMessage] = React.useState('');
  const [hasFilter, setHasFilter] = React.useState(false);

  async function handleSearch() {
    if (searchText.length > 0) {
      setHasFilter(true);
      const response = await api.get(`tutorial/search/${searchText}`);
      if (response.data.data.length > 0) {
        setNoResultMessage('');
        setFilteredData(response.data.data);
      } else {
        setNoResultMessage('Nenhum tutorial foi retornado.');
      }

      if (response.data.status === 500) {
        Alert.alert(
          'Falha ao procurar tutoriais',
          'Houve um problema ao tentar buscar tutoriais. Tente novamente mais tarde.',
        );
      } else {
        //TODO redirecionar para a rota de admin ou usuário comum.
        console.log(response.data.data);
      }
    }
  }

  function handleChangeSearchText(searchText) {
    if (!searchText.length) {
      setFilteredData(tutorials);
      setNoResultMessage('');
      setSearchText('');
      setHasFilter(false);
    } else setSearchText(searchText);
  }

  function filterTutorialsForOS(tutorials) {
    return tutorials.filter(tutorial => {
      const os = (tutorial.operatingSystem ?? '').trim();
      if (os.length === 0) {
        return true;
      }

      return os.toLowerCase() === Platform.OS;
    });
  }

  React.useEffect(() => {
    async function fetchTutorials() {
      const { id } = route.params;

      try {
        const response = await api.get(`/app/tutorials/${id}`);
        const data = filterTutorialsForOS(response.data.data);
        setTutorials(data);
        setFilteredData(data);
      } catch (error) {
        console.warn(error);
      }
    }
    fetchTutorials();
  }, []);

  const emptyMessage = (
    text = 'Não existem tutoriais deste aplicativo para o seu sistema operacional.',
  ) => (
    <View style={styles.emptyMessageContainer}>
      <Text style={styles.emptyMessage}>{text}</Text>
    </View>
  );

  return (
    <View style={styles.screen}>
      <HeaderComponent leftButton leftButtonAction={() => navigation.goBack()}>
        <>
          {hasFilter ? (
            <Text style={styles.descriptionText}>Tutoriais</Text>
          ) : (
            <Text style={styles.descriptionText}>
              Tutoriais do{' '}
              <Text style={styles.textBold}>{route.params.name}</Text>{' '}
            </Text>
          )}

          <SearchBarComponent
            handleClick={handleSearch}
            sendSearch={value => handleChangeSearchText(value)}
          />
        </>
      </HeaderComponent>
      <BodyComponent>
        {!noResultMessage && (filteredData.length ?? 0) > 0 ? (
          <ListComponent
            appoios={filteredData}
            action={id => navigation.navigate('Tutorial', { id })}
          />
        ) : (
          emptyMessage()
        )}
      </BodyComponent>
    </View>
  );
}
const styles = StyleSheet.create({
  screen: {
    flex: 1,
    backgroundColor: colors.primary,
  },
  emptyMessageContainer: { margin: '10%', justifyContent: 'center' },
  header: {
    alignItems: 'center',
    justifyContent: 'center',
    color: colors.textWhite,
    fontSize: 30,
    fontWeight: 'bold',
  },
  headerDescription: {
    alignItems: 'center',
    textAlign: 'center',
    justifyContent: 'center',
    color: colors.textWhite,
    fontSize: 25,
  },
  textBold: {
    fontWeight: 'bold',
  },
  descriptionText: {
    color: colors.textWhite,
    fontSize: 22,
    textAlign: 'center',
    marginBottom: 10,
  },
  emptyMessage: {
    color: colors.textDisabled,
    fontSize: 20,
    fontWeight: 'bold',
    textAlign: 'center',
    alignSelf: 'center',
  },
});
